@@ -1,7 +1,7 @@
 """
 Type annotations for forecastquery service client.
 
-[Open documentation](./client.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html)
 
 Usage::
 
@@ -16,7 +16,7 @@ from typing import Any, Dict, Type
 
 from botocore.client import ClientMeta
 
-from .type_defs import QueryForecastResponseTypeDef
+from mypy_boto3_forecastquery.type_defs import QueryForecastResponseTypeDef
 
 __all__ = ("ForecastQueryServiceClient",)
 
@@ -40,8 +40,8 @@ class Exceptions:
 
 class ForecastQueryServiceClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/forecastquery.html#ForecastQueryService.Client)
-    [Show boto3-stubs documentation](./client.md)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/forecastquery.html#ForecastQueryService.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html)
     """
 
     meta: ClientMeta
@@ -49,8 +49,8 @@ class ForecastQueryServiceClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html#can-paginate)
         """
 
     def generate_presigned_url(
@@ -61,8 +61,8 @@ class ForecastQueryServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html#generate-presigned-url)
         """
 
     def query_forecast(
@@ -74,6 +74,6 @@ class ForecastQueryServiceClient:
         NextToken: str = None,
     ) -> QueryForecastResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
-        [Show boto3-stubs documentation](./client.md#query-forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client.html#query-forecast)
         """
